// java wrapper for vtkXMLUtilities object
//

package vtk;
import vtk.*;

public class vtkXMLUtilities extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long ReadElementFromString_2(String id0,int id1);
  public vtkXMLDataElement ReadElementFromString(String id0,int id1) {
    long temp = ReadElementFromString_2(id0,id1);

    if (temp == 0) return null;
    return (vtkXMLDataElement)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long ReadElementFromFile_3(String id0,int id1);
  public vtkXMLDataElement ReadElementFromFile(String id0,int id1) {
    long temp = ReadElementFromFile_3(id0,id1);

    if (temp == 0) return null;
    return (vtkXMLDataElement)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void FactorElements_4(vtkXMLDataElement id0);
  public void FactorElements(vtkXMLDataElement id0)
    { FactorElements_4(id0); }

  private native void UnFactorElements_5(vtkXMLDataElement id0);
  public void UnFactorElements(vtkXMLDataElement id0)
    { UnFactorElements_5(id0); }

  public vtkXMLUtilities() { super(); }

  public vtkXMLUtilities(long id) { super(id); }
  public native long   VTKInit();

}
